==> uxkit-0.0.2.tgz: package/built/UXKit/AlertView.js <==
/// <reference path="../../typings/tsd.d.ts"/>
import * as React from "react";
import * as RN from "react-native";
import { View } from "./View";
import { ViewController } from "./ViewController";
import { PixelLine } from "./PixelLine";
import { TextButton } from "./Button";
import { Label } from "./Label";
import { Font } from "./Font";
import { TapGestureRecognizer } from "./GestureRecognizer";
import { Text, TextParagraphStyle } from "./Text";
import { ControlEvents, TextAlignment, GestureRecognizerState } from "./Enum";
/**
 * AlertView
 */
export class AlertView extends ViewController {
    constructor(props) {
        super(props);
        this.title = "";
        this.message = "";
        this.buttonTitles = [];
        this.reversedIndexes = [];
        this.dangerIndexes = [];
        this.cancelButtonIndex = -1;
        // Private 
        this.alphaPresented = false;
        this.contentPresented = false;
        this.title = props.title;
        this.message = props.message;
        this.buttonTitles = props.buttonTitles;
        this.reversedIndexes = props.reversedIndexes;
        this.cancelButtonIndex = props.cancelButtonIndex;
        this.handler = props.handler;
        this.cancelGesture = new TapGestureRecognizer((state) => {
            if (this.props.cancelButtonIndex >= 0 && state == GestureRecognizerState.Ended) {
                this.props.handler && this.props.handler(this.props.cancelButtonIndex);
                this.dismissViewController(false);
            }
        });
    }
    static show(inViewController, title, message, buttonTitles = ["OK"], cancelButtonIndex = 0, handler) {
        inViewController.presentViewController(AlertView, {
            title: title,
            message: message,
            buttonTitles: buttonTitles,
            cancelButtonIndex: cancelButtonIndex,
            handler: handler,
        }, false);
    }
    loadView() {
        return (React.createElement(View, {frame: { x: 0, y: 0, mx: 0, my: 0 }, animatable: true, gestureRecognizers: [this.cancelGesture], backgroundColor: "#00000090", alpha: this.alphaPresented ? 1.0 : 0.0}, React.createElement(View, {animatable: true, frame: { cx: 0, cy: 0, width: RN.Dimensions.get('window').width * 0.75 }, alpha: this.alphaPresented ? 1.0 : 0.0, transform: { scaleX: this.contentPresented ? 1.0 : 0.8, scaleY: this.contentPresented ? 1.0 : 0.8 }, backgroundColor: "white", cornerRadius: 6.0}, this._renderTitle(), this._renderMessage(), this._renderButtons())));
    }
    viewWillAppear() {
        View.setAnimate(() => {
            this.alphaPresented = true;
            this.setState({});
        }, 500);
        setTimeout(() => {
            View.setAnimate(() => {
                this.contentPresented = true;
                this.setState({});
            }, 500, 'spring', { friction: 10.0, tension: 160.0, toValue: 0.0 });
        }, 100);
    }
    dismissViewController(animated) {
        View.setAnimate(() => {
            this.contentPresented = false;
            this.alphaPresented = false;
            this.setState({});
        }, null, 'spring', { friction: 16.0, tension: 200.0, toValue: 0.0 }, () => {
            super.dismissViewController(false);
        });
    }
    _renderTitle() {
        if (this.props.title) {
            return (React.createElement(RN.View, null, React.createElement(RN.View, {style: { height: 20 }}), React.createElement(Label, {style: { alignSelf: 'center' }, text: this.props.title, textAlignment: TextAlignment.Center, font: Font.boldSystemFontOfSize(17)})));
        }
        else {
            return (React.createElement(View, {style: { height: 4 }}));
        }
    }
    _renderMessage() {
        let paragraphStyle = new TextParagraphStyle();
        paragraphStyle.lineHeight = 26.0;
        if (this.props.message) {
            return (React.createElement(RN.View, {style: { marginLeft: 20, marginRight: 20 }}, React.createElement(RN.View, {style: { height: 10 }}), React.createElement(Label, {style: { alignSelf: 'center' }, textAlignment: TextAlignment.Center}, React.createElement(Text, {font: Font.fontWithSize(16), paragraph: paragraphStyle, foregroundColor: "#5a5a5a"}, this.props.message)), React.createElement(RN.View, {style: { height: RN.Platform.OS == "ios" ? 24 : 16 }})));
        }
        else {
            return (React.createElement(RN.View, {style: { height: 18 }}));
        }
    }
    _renderButtons() {
        if (this.props.buttonTitles.length > 0 && this.props.buttonTitles.length <= 2) {
            let buttons = [];
            for (var i = 0; i < this.props.buttonTitles.length; i++) {
                var buttonTitle = this.props.buttonTitles[i];
                buttons.push(React.createElement(TextButton, {key: "button_" + i, tag: i, title: buttonTitle, titleLabelProps: { font: Font.fontWithSize(16) }, style: { height: 44, flex: 1 }, handler: (event, sender) => {
                    if (event == ControlEvents.TouchUpInside) {
                        this.props.handler && this.props.handler(sender.props.tag);
                        this.dismissViewController(false);
                    }
                }}));
                if (i + 1 < this.props.buttonTitles.length) {
                    buttons.push(React.createElement(PixelLine, {key: "line_" + i, vertical: true}));
                }
            }
            return (React.createElement(RN.View, null, React.createElement(PixelLine, null), React.createElement(RN.View, {style: { flexDirection: 'row' }}, buttons)));
        }
        else if (this.props.buttonTitles.length > 2) {
            let buttons = [];
            for (var i = 0; i < this.props.buttonTitles.length; i++) {
                var buttonTitle = this.props.buttonTitles[i];
                buttons.push(React.createElement(TextButton, {key: "button_" + i, tag: i, title: buttonTitle, titleLabelProps: { font: Font.fontWithSize(16) }, style: { height: 44, flex: 1 }, handler: (event, sender) => {
                    if (event == ControlEvents.TouchUpInside) {
                        this.props.handler && this.props.handler(sender.props.tag);
                        this.dismissViewController(false);
                    }
                }}));
                if (i + 1 < this.props.buttonTitles.length) {
                    buttons.push(React.createElement(PixelLine, {key: "line_" + i}));
                }
            }
            return (React.createElement(RN.View, null, React.createElement(PixelLine, null), React.createElement(RN.View, {style: { flexDirection: 'column' }}, buttons)));
        }
        else {
            return null;
        }
    }
}
AlertView.defaultProps = {
    style: {
        backgroundColor: "#ffffff00"
    },
};

==> uxkit-0.0.3.tgz: package/built/UXKit/AlertView.js <==
/// <reference path="../../typings/tsd.d.ts"/>
import * as React from "react";
import * as RN from "react-native";
import { View } from "./View";
import { ViewController } from "./ViewController";
import { PixelLine } from "./PixelLine";
import { TextButton } from "./Button";
import { Label } from "./Label";
import { Font } from "./Font";
import { TapGestureRecognizer } from "./GestureRecognizer";
import { Text, TextParagraphStyle } from "./Text";
import { ControlEvents, TextAlignment, GestureRecognizerState } from "./Enum";
/**
 * AlertView
 */
export class AlertView extends ViewController {
    constructor(props) {
        super(props);
        this.title = "";
        this.message = "";
        this.buttonTitles = [];
        this.reversedIndexes = [];
        this.dangerIndexes = [];
        this.cancelButtonIndex = -1;
        // Private 
        this.alphaPresented = false;
        this.contentPresented = false;
        this.title = props.title;
        this.message = props.message;
        this.buttonTitles = props.buttonTitles;
        this.reversedIndexes = props.reversedIndexes;
        this.cancelButtonIndex = props.cancelButtonIndex;
        this.handler = props.handler;
        this.cancelGesture = new TapGestureRecognizer((state) => {
            if (this.props.cancelButtonIndex >= 0 && state == GestureRecognizerState.Ended) {
                this.props.handler && this.props.handler(this.props.cancelButtonIndex);
                this.dismissViewController(false);
            }
        });
    }
    static show(inViewController, title, message, buttonTitles = ["OK"], cancelButtonIndex = 0, handler) {
        inViewController.presentViewController(React.createElement(AlertView, {title: title, message: message, buttonTitles: buttonTitles, cancelButtonIndex: cancelButtonIndex, handler: handler}), false);
    }
    loadView() {
        return (React.createElement(View, {frame: { x: 0, y: 0, mx: 0, my: 0 }, animatable: true, gestureRecognizers: [this.cancelGesture], backgroundColor: "#00000090", alpha: this.alphaPresented ? 1.0 : 0.0}, React.createElement(View, {animatable: true, frame: { cx: 0, cy: 0, width: RN.Dimensions.get('window').width * 0.75 }, alpha: this.alphaPresented ? 1.0 : 0.0, transform: { scaleX: this.contentPresented ? 1.0 : 0.8, scaleY: this.contentPresented ? 1.0 : 0.8 }, backgroundColor: "white", cornerRadius: 6.0}, this._renderTitle(), this._renderMessage(), this._renderButtons())));
    }
    viewWillAppear() {
        View.setAnimate(() => {
            this.alphaPresented = true;
            this.setState({});
        }, 500);
        setTimeout(() => {
            View.setAnimate(() => {
                this.contentPresented = true;
                this.setState({});
            }, 500, 'spring', { friction: 10.0, tension: 160.0, toValue: 0.0 });
        }, 100);
    }
    dismissViewController(animated) {
        View.setAnimate(() => {
            this.contentPresented = false;
            this.alphaPresented = false;
            this.setState({});
        }, null, 'spring', { friction: 16.0, tension: 200.0, toValue: 0.0 }, () => {
            super.dismissViewController(false);
        });
    }
    _renderTitle() {
        if (this.props.title) {
            return (React.createElement(RN.View, null, React.createElement(RN.View, {style: { height: 20 }}), React.createElement(Label, {style: { alignSelf: 'center' }, text: this.props.title, textAlignment: TextAlignment.Center, font: Font.boldSystemFontOfSize(17)})));
        }
        else {
            return (React.createElement(View, {style: { height: 4 }}));
        }
    }
    _renderMessage() {
        let paragraphStyle = new TextParagraphStyle();
        paragraphStyle.lineHeight = 26.0;
        if (this.props.message) {
            return (React.createElement(RN.View, {style: { marginLeft: 20, marginRight: 20 }}, React.createElement(RN.View, {style: { height: 10 }}), React.createElement(Label, {style: { alignSelf: 'center' }, textAlignment: TextAlignment.Center}, React.createElement(Text, {font: Font.fontWithSize(16), paragraph: paragraphStyle, foregroundColor: "#5a5a5a"}, this.props.message)), React.createElement(RN.View, {style: { height: RN.Platform.OS == "ios" ? 24 : 16 }})));
        }
        else {
            return (React.createElement(RN.View, {style: { height: 18 }}));
        }
    }
    _renderButtons() {
        if (this.props.buttonTitles.length > 0 && this.props.buttonTitles.length <= 2) {
            let buttons = [];
            for (var i = 0; i < this.props.buttonTitles.length; i++) {
                var buttonTitle = this.props.buttonTitles[i];
                buttons.push(React.createElement(TextButton, {key: "button_" + i, tag: i, title: buttonTitle, titleLabelProps: { font: Font.fontWithSize(16) }, style: { height: 44, flex: 1 }, handler: (event, sender) => {
                    if (event == ControlEvents.TouchUpInside) {
                        this.props.handler && this.props.handler(sender.props.tag);
                        this.dismissViewController(false);
                    }
                }}));
                if (i + 1 < this.props.buttonTitles.length) {
                    buttons.push(React.createElement(PixelLine, {key: "line_" + i, vertical: true, right: 0}));
                }
            }
            return (React.createElement(RN.View, null, React.createElement(PixelLine, {bottom: 0}), React.createElement(RN.View, {style: { flexDirection: 'row' }}, buttons)));
        }
        else if (this.props.buttonTitles.length > 2) {
            let buttons = [];
            for (var i = 0; i < this.props.buttonTitles.length; i++) {
                var buttonTitle = this.props.buttonTitles[i];
                buttons.push(React.createElement(TextButton, {key: "button_" + i, tag: i, title: buttonTitle, titleLabelProps: { font: Font.fontWithSize(16) }, style: { height: 44, flex: 1 }, handler: (event, sender) => {
                    if (event == ControlEvents.TouchUpInside) {
                        this.props.handler && this.props.handler(sender.props.tag);
                        this.dismissViewController(false);
                    }
                }}));
                if (i + 1 < this.props.buttonTitles.length) {
                    buttons.push(React.createElement(PixelLine, {key: "line_" + i, bottom: 0}));
                }
            }
            return (React.createElement(RN.View, null, React.createElement(PixelLine, {bottom: 0}), React.createElement(RN.View, {style: { flexDirection: 'column' }}, buttons)));
        }
        else {
            return null;
        }
    }
}
AlertView.defaultProps = {
    style: {
        backgroundColor: "#ffffff00"
    },
};
